netapp_ontap.models.metrocluster_remote API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.metrocluster_remote`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class MetroclusterRemoteSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the MetroclusterRemote object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `cluster GET POST PATCH`

    The cluster field of the metrocluster_remote.

  `configuration_state GET`

    Indicates the state of the remote cluster configuration.

    Valid choices:

    - configuration_error
    - configured
    - not_configured
    - not_reachable
    - partially_configured
    - unknown
  `mode GET`

    Specifies the mode of operation of the remote cluster.

    Valid choices:

    - normal
    - not_configured
    - not_reachable
    - partial_switchback
    - partial_switchover
    - switchover
    - unknown
    - waiting_for_switchback
  `periodic_check_enabled GET`

    Indicates whether or not a periodic check is enabled on the remote cluster.